from typing import Any
from typing import Callable
from typing import Literal
from typing import Optional
from typing import Sequence
from typing import Tuple
from typing import Type
from typing import TypeVar

from gi.repository import Gio
from gi.repository import GLib
from gi.repository import GObject

WALLPAPER_TARGET_BOTH: int = 0
_lock = ...  # FIXME Constant
_namespace: str = "Xdp"
_version: str = "1.0"

class Parent(GObject.GBoxed):
    def copy(self) -> Parent: ...
    def free(self) -> None: ...

class Portal(GObject.Object, Gio.Initable):
    """
    :Constructors:

    ::

        Portal(**properties)
        initable_new() -> Xdp.Portal or None
        new() -> Xdp.Portal

    Object XdpPortal

    Signals from XdpPortal:
      spawn-exited (guint, guint)
      session-state-changed (gboolean, XdpLoginSessionState)
      update-available (gchararray, gchararray, gchararray)
      update-progress (guint, guint, guint, XdpUpdateStatus, gchararray, gchararray)
      location-updated (gdouble, gdouble, gdouble, gdouble, gdouble, gdouble, gchararray, gint64, gint64)
      notification-action-invoked (gchararray, gchararray, GVariant)

    Signals from GObject:
      notify (GParam)
    """

    def access_camera(
        self,
        parent: Optional[Parent],
        flags: CameraFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def access_camera_finish(self, result: Gio.AsyncResult) -> bool: ...
    def add_notification(
        self,
        id: str,
        notification: GLib.Variant,
        flags: NotificationFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def add_notification_finish(self, result: Gio.AsyncResult) -> bool: ...
    def compose_email(
        self,
        parent: Optional[Parent],
        addresses: Optional[Sequence[str]],
        cc: Optional[Sequence[str]],
        bcc: Optional[Sequence[str]],
        subject: Optional[str],
        body: Optional[str],
        attachments: Optional[Sequence[str]],
        flags: EmailFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def compose_email_finish(self, result: Gio.AsyncResult) -> bool: ...
    def create_remote_desktop_session(
        self,
        devices: DeviceType,
        outputs: OutputType,
        flags: RemoteDesktopFlags,
        cursor_mode: CursorMode,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def create_remote_desktop_session_finish(
        self, result: Gio.AsyncResult
    ) -> Session: ...
    def create_screencast_session(
        self,
        outputs: OutputType,
        flags: ScreencastFlags,
        cursor_mode: CursorMode,
        persist_mode: PersistMode,
        restore_token: Optional[str] = None,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def create_screencast_session_finish(self, result: Gio.AsyncResult) -> Session: ...
    def dynamic_launcher_get_desktop_entry(self, desktop_file_id: str) -> str: ...
    def dynamic_launcher_get_icon(
        self,
        desktop_file_id: str,
        out_icon_format: Optional[str] = None,
        out_icon_size: Optional[int] = None,
    ) -> GLib.Variant: ...
    def dynamic_launcher_install(
        self, token: str, desktop_file_id: str, desktop_entry: str
    ) -> bool: ...
    def dynamic_launcher_launch(
        self, desktop_file_id: str, activation_token: str
    ) -> bool: ...
    def dynamic_launcher_prepare_install(
        self,
        parent: Optional[Parent],
        name: str,
        icon_v: GLib.Variant,
        launcher_type: LauncherType,
        target: Optional[str],
        editable_name: bool,
        editable_icon: bool,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def dynamic_launcher_prepare_install_finish(
        self, result: Gio.AsyncResult
    ) -> GLib.Variant: ...
    def dynamic_launcher_request_install_token(
        self, name: str, icon_v: GLib.Variant
    ) -> str: ...
    def dynamic_launcher_uninstall(self, desktop_file_id: str) -> bool: ...
    def get_user_information(
        self,
        parent: Optional[Parent],
        reason: Optional[str],
        flags: UserInformationFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def get_user_information_finish(self, result: Gio.AsyncResult) -> GLib.Variant: ...
    @classmethod
    def initable_new(cls) -> Optional[Portal]: ...
    def is_camera_present(self) -> bool: ...
    def location_monitor_start(
        self,
        parent: Optional[Parent],
        distance_threshold: int,
        time_threshold: int,
        accuracy: LocationAccuracy,
        flags: LocationMonitorFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def location_monitor_start_finish(self, result: Gio.AsyncResult) -> bool: ...
    def location_monitor_stop(self) -> None: ...
    @classmethod
    def new(cls) -> Portal: ...
    def open_directory(
        self,
        parent: Parent,
        uri: str,
        flags: OpenUriFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def open_directory_finish(self, result: Gio.AsyncResult) -> bool: ...
    def open_file(
        self,
        parent: Optional[Parent],
        title: str,
        filters: Optional[GLib.Variant],
        current_filter: Optional[GLib.Variant],
        choices: Optional[GLib.Variant],
        flags: OpenFileFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def open_file_finish(self, result: Gio.AsyncResult) -> GLib.Variant: ...
    def open_pipewire_remote_for_camera(self) -> int: ...
    def open_uri(
        self,
        parent: Parent,
        uri: str,
        flags: OpenUriFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def open_uri_finish(self, result: Gio.AsyncResult) -> bool: ...
    def pick_color(
        self,
        parent: Optional[Parent] = None,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def pick_color_finish(self, result: Gio.AsyncResult) -> GLib.Variant: ...
    def prepare_print(
        self,
        parent: Optional[Parent],
        title: str,
        settings: Optional[GLib.Variant],
        page_setup: Optional[GLib.Variant],
        flags: PrintFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def prepare_print_finish(self, result: Gio.AsyncResult) -> GLib.Variant: ...
    def print_file(
        self,
        parent: Optional[Parent],
        title: str,
        token: int,
        file: str,
        flags: PrintFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def print_file_finish(self, result: Gio.AsyncResult) -> bool: ...
    def remove_notification(self, id: str) -> None: ...
    def request_background(
        self,
        parent: Optional[Parent],
        reason: Optional[str],
        commandline: Sequence[str],
        flags: BackgroundFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *user_data: Any,
    ) -> None: ...
    def request_background_finish(self, result: Gio.AsyncResult) -> bool: ...
    @staticmethod
    def running_under_flatpak() -> bool: ...
    @staticmethod
    def running_under_sandbox() -> bool: ...
    @staticmethod
    def running_under_snap() -> bool: ...
    def save_file(
        self,
        parent: Optional[Parent],
        title: str,
        current_name: Optional[str],
        current_folder: Optional[str],
        current_file: Optional[str],
        filters: Optional[GLib.Variant],
        current_filter: Optional[GLib.Variant],
        choices: Optional[GLib.Variant],
        flags: SaveFileFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def save_file_finish(self, result: Gio.AsyncResult) -> GLib.Variant: ...
    def save_files(
        self,
        parent: Optional[Parent],
        title: str,
        current_name: Optional[str],
        current_folder: Optional[str],
        files: GLib.Variant,
        choices: Optional[GLib.Variant],
        flags: SaveFileFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def save_files_finish(self, result: Gio.AsyncResult) -> GLib.Variant: ...
    def session_inhibit(
        self,
        parent: Optional[Parent],
        reason: Optional[str],
        flags: InhibitFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def session_inhibit_finish(self, result: Gio.AsyncResult) -> int: ...
    def session_monitor_query_end_response(self) -> None: ...
    def session_monitor_start(
        self,
        parent: Optional[Parent],
        flags: SessionMonitorFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def session_monitor_start_finish(self, result: Gio.AsyncResult) -> bool: ...
    def session_monitor_stop(self) -> None: ...
    def session_uninhibit(self, id: int) -> None: ...
    def set_background_status(
        self,
        status_message: Optional[str] = None,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def set_background_status_finish(self, result: Gio.AsyncResult) -> bool: ...
    def set_wallpaper(
        self,
        parent: Optional[Parent],
        uri: str,
        flags: WallpaperFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def set_wallpaper_finish(self, result: Gio.AsyncResult) -> bool: ...
    def spawn(
        self,
        cwd: str,
        argv: Sequence[str],
        fds: Optional[Sequence[int]],
        map_to: Optional[Sequence[int]],
        env: Optional[Sequence[str]],
        flags: SpawnFlags,
        sandbox_expose: Optional[Sequence[str]] = None,
        sandbox_expose_ro: Optional[Sequence[str]] = None,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def spawn_finish(self, result: Gio.AsyncResult) -> int: ...
    def spawn_signal(self, pid: int, signal: int, to_process_group: bool) -> None: ...
    def take_screenshot(
        self,
        parent: Optional[Parent],
        flags: ScreenshotFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def take_screenshot_finish(self, result: Gio.AsyncResult) -> Optional[str]: ...
    def trash_file(
        self,
        path: str,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def trash_file_finish(self, result: Gio.AsyncResult) -> bool: ...
    def update_install(
        self,
        parent: Parent,
        flags: UpdateInstallFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def update_install_finish(self, result: Gio.AsyncResult) -> bool: ...
    def update_monitor_start(
        self,
        flags: UpdateMonitorFlags,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def update_monitor_start_finish(self, result: Gio.AsyncResult) -> bool: ...
    def update_monitor_stop(self) -> None: ...

class PortalClass(GObject.GPointer):
    """
    :Constructors:

    ::

        PortalClass()
    """

    parent_class: GObject.ObjectClass = ...

class Session(GObject.Object):
    """
    :Constructors:

    ::

        Session(**properties)

    Object XdpSession

    Signals from XdpSession:
      closed ()

    Signals from GObject:
      notify (GParam)
    """

    def close(self) -> None: ...
    def connect_to_eis(self) -> int: ...
    def get_devices(self) -> DeviceType: ...
    def get_persist_mode(self) -> PersistMode: ...
    def get_restore_token(self) -> Optional[str]: ...
    def get_session_state(self) -> SessionState: ...
    def get_session_type(self) -> SessionType: ...
    def get_streams(self) -> GLib.Variant: ...
    def keyboard_key(self, keysym: bool, key: int, state: KeyState) -> None: ...
    def open_pipewire_remote(self) -> int: ...
    def pointer_axis(self, finish: bool, dx: float, dy: float) -> None: ...
    def pointer_axis_discrete(self, axis: DiscreteAxis, steps: int) -> None: ...
    def pointer_button(self, button: int, state: ButtonState) -> None: ...
    def pointer_motion(self, dx: float, dy: float) -> None: ...
    def pointer_position(self, stream: int, x: float, y: float) -> None: ...
    def start(
        self,
        parent: Optional[Parent] = None,
        cancellable: Optional[Gio.Cancellable] = None,
        callback: Optional[Callable[..., None]] = None,
        *data: Any,
    ) -> None: ...
    def start_finish(self, result: Gio.AsyncResult) -> bool: ...
    def touch_down(self, stream: int, slot: int, x: float, y: float) -> None: ...
    def touch_position(self, stream: int, slot: int, x: float, y: float) -> None: ...
    def touch_up(self, slot: int) -> None: ...

class SessionClass(GObject.GPointer):
    """
    :Constructors:

    ::

        SessionClass()
    """

    parent_class: GObject.ObjectClass = ...

class BackgroundFlags(GObject.GFlags):
    ACTIVATABLE = 2
    AUTOSTART = 1
    NONE = 0

class CursorMode(GObject.GFlags):
    EMBEDDED = 2
    HIDDEN = 1
    METADATA = 4

class DeviceType(GObject.GFlags):
    KEYBOARD = 1
    NONE = 0
    POINTER = 2
    TOUCHSCREEN = 4

class InhibitFlags(GObject.GFlags):
    IDLE = 8
    LOGOUT = 1
    SUSPEND = 4
    USER_SWITCH = 2

class LauncherType(GObject.GFlags):
    APPLICATION = 1
    WEBAPP = 2

class OpenFileFlags(GObject.GFlags):
    MULTIPLE = 1
    NONE = 0

class OpenUriFlags(GObject.GFlags):
    ASK = 1
    NONE = 0
    WRITABLE = 2

class OutputType(GObject.GFlags):
    MONITOR = 1
    NONE = 0
    VIRTUAL = 4
    WINDOW = 2

class RemoteDesktopFlags(GObject.GFlags):
    MULTIPLE = 1
    NONE = 0

class ScreencastFlags(GObject.GFlags):
    MULTIPLE = 1
    NONE = 0

class ScreenshotFlags(GObject.GFlags):
    INTERACTIVE = 1
    NONE = 0

class SpawnFlags(GObject.GFlags):
    CLEARENV = 1
    LATEST = 2
    NONE = 0
    NO_NETWORK = 8
    SANDBOX = 4
    WATCH = 16

class WallpaperFlags(GObject.GFlags):
    BACKGROUND = 1
    LOCKSCREEN = 2
    NONE = 0
    PREVIEW = 4

class ButtonState(GObject.GEnum):
    PRESSED = 1
    RELEASED = 0

class CameraFlags(GObject.GEnum):
    NONE = 0

class DiscreteAxis(GObject.GEnum):
    HORIZONTAL_SCROLL = 0
    VERTICAL_SCROLL = 1

class EmailFlags(GObject.GEnum):
    NONE = 0

class KeyState(GObject.GEnum):
    PRESSED = 1
    RELEASED = 0

class LocationAccuracy(GObject.GEnum):
    CITY = 2
    COUNTRY = 1
    EXACT = 5
    NEIGHBORHOOD = 3
    NONE = 0
    STREET = 4

class LocationMonitorFlags(GObject.GEnum):
    NONE = 0

class LoginSessionState(GObject.GEnum):
    ENDING = 3
    QUERY_END = 2
    RUNNING = 1

class NotificationFlags(GObject.GEnum):
    NONE = 0

class PersistMode(GObject.GEnum):
    NONE = 0
    PERSISTENT = 2
    TRANSIENT = 1

class PrintFlags(GObject.GEnum):
    NONE = 0

class SaveFileFlags(GObject.GEnum):
    NONE = 0

class SessionMonitorFlags(GObject.GEnum):
    NONE = 0

class SessionState(GObject.GEnum):
    ACTIVE = 1
    CLOSED = 2
    INITIAL = 0

class SessionType(GObject.GEnum):
    REMOTE_DESKTOP = 1
    SCREENCAST = 0

class UpdateInstallFlags(GObject.GEnum):
    NONE = 0

class UpdateMonitorFlags(GObject.GEnum):
    NONE = 0

class UpdateStatus(GObject.GEnum):
    DONE = 2
    EMPTY = 1
    FAILED = 3
    RUNNING = 0

class UserInformationFlags(GObject.GEnum):
    NONE = 0



import typing

from gi.repository import GLib
from gi.repository import GObject

T = typing.TypeVar("T")

MAJOR_VERSION: int = 1
MICRO_VERSION: int = 0
MINOR_VERSION: int = 84
TYPE_TAG_N_TYPES: int = 22
_lock = ...  # FIXME Constant
_namespace: str = "GIRepository"
_version: str = "2.0"

def arg_info_get_closure(info: BaseInfo) -> int: ...
def arg_info_get_destroy(info: BaseInfo) -> int: ...
def arg_info_get_direction(info: BaseInfo) -> Direction: ...
def arg_info_get_ownership_transfer(info: BaseInfo) -> Transfer: ...
def arg_info_get_scope(info: BaseInfo) -> ScopeType: ...
def arg_info_get_type(info: BaseInfo) -> BaseInfo: ...
def arg_info_is_caller_allocates(info: BaseInfo) -> bool: ...
def arg_info_is_optional(info: BaseInfo) -> bool: ...
def arg_info_is_return_value(info: BaseInfo) -> bool: ...
def arg_info_is_skip(info: BaseInfo) -> bool: ...
def arg_info_load_type(info: BaseInfo) -> BaseInfo: ...
def arg_info_may_be_null(info: BaseInfo) -> bool: ...
def callable_info_can_throw_gerror(info: BaseInfo) -> bool: ...
def callable_info_get_arg(info: BaseInfo, n: int) -> BaseInfo: ...
def callable_info_get_caller_owns(info: BaseInfo) -> Transfer: ...
def callable_info_get_instance_ownership_transfer(info: BaseInfo) -> Transfer: ...
def callable_info_get_n_args(info: BaseInfo) -> int: ...
def callable_info_get_return_attribute(info: BaseInfo, name: str) -> str: ...
def callable_info_get_return_type(info: BaseInfo) -> BaseInfo: ...
def callable_info_invoke(
    info: BaseInfo,
    function: None,
    in_args: typing.Sequence[Argument],
    out_args: typing.Sequence[Argument],
    return_value: Argument,
    is_method: bool,
    throws: bool,
) -> bool: ...
def callable_info_is_method(info: BaseInfo) -> bool: ...
def callable_info_iterate_return_attributes(
    info: BaseInfo,
) -> typing.Tuple[bool, AttributeIter, str, str]: ...
def callable_info_load_arg(info: BaseInfo, n: int) -> BaseInfo: ...
def callable_info_load_return_type(info: BaseInfo) -> BaseInfo: ...
def callable_info_may_return_null(info: BaseInfo) -> bool: ...
def callable_info_skip_return(info: BaseInfo) -> bool: ...
def cclosure_marshal_generic(
    closure: typing.Callable[..., typing.Any],
    return_gvalue: typing.Any,
    n_param_values: int,
    param_values: typing.Any,
    invocation_hint: None,
    marshal_data: None,
) -> None: ...
def constant_info_get_type(info: BaseInfo) -> BaseInfo: ...
def enum_info_get_error_domain(info: BaseInfo) -> str: ...
def enum_info_get_method(info: BaseInfo, n: int) -> BaseInfo: ...
def enum_info_get_n_methods(info: BaseInfo) -> int: ...
def enum_info_get_n_values(info: BaseInfo) -> int: ...
def enum_info_get_storage_type(info: BaseInfo) -> TypeTag: ...
def enum_info_get_value(info: BaseInfo, n: int) -> BaseInfo: ...
def field_info_get_flags(info: BaseInfo) -> FieldInfoFlags: ...
def field_info_get_offset(info: BaseInfo) -> int: ...
def field_info_get_size(info: BaseInfo) -> int: ...
def field_info_get_type(info: BaseInfo) -> BaseInfo: ...
def function_info_get_flags(info: BaseInfo) -> FunctionInfoFlags: ...
def function_info_get_property(info: BaseInfo) -> BaseInfo: ...
def function_info_get_symbol(info: BaseInfo) -> str: ...
def function_info_get_vfunc(info: BaseInfo) -> BaseInfo: ...
def get_major_version() -> int: ...
def get_micro_version() -> int: ...
def get_minor_version() -> int: ...
def info_new(
    type: InfoType, container: BaseInfo, typelib: Typelib, offset: int
) -> BaseInfo: ...
def info_type_to_string(type: InfoType) -> str: ...
def interface_info_find_method(info: BaseInfo, name: str) -> BaseInfo: ...
def interface_info_find_signal(info: BaseInfo, name: str) -> BaseInfo: ...
def interface_info_find_vfunc(info: BaseInfo, name: str) -> BaseInfo: ...
def interface_info_get_constant(info: BaseInfo, n: int) -> BaseInfo: ...
def interface_info_get_iface_struct(info: BaseInfo) -> BaseInfo: ...
def interface_info_get_method(info: BaseInfo, n: int) -> BaseInfo: ...
def interface_info_get_n_constants(info: BaseInfo) -> int: ...
def interface_info_get_n_methods(info: BaseInfo) -> int: ...
def interface_info_get_n_prerequisites(info: BaseInfo) -> int: ...
def interface_info_get_n_properties(info: BaseInfo) -> int: ...
def interface_info_get_n_signals(info: BaseInfo) -> int: ...
def interface_info_get_n_vfuncs(info: BaseInfo) -> int: ...
def interface_info_get_prerequisite(info: BaseInfo, n: int) -> BaseInfo: ...
def interface_info_get_property(info: BaseInfo, n: int) -> BaseInfo: ...
def interface_info_get_signal(info: BaseInfo, n: int) -> BaseInfo: ...
def interface_info_get_vfunc(info: BaseInfo, n: int) -> BaseInfo: ...
def invoke_error_quark() -> int: ...
def object_info_find_method(info: BaseInfo, name: str) -> typing.Optional[BaseInfo]: ...
def object_info_find_method_using_interfaces(
    info: BaseInfo, name: str
) -> typing.Tuple[typing.Optional[BaseInfo], BaseInfo]: ...
def object_info_find_signal(info: BaseInfo, name: str) -> typing.Optional[BaseInfo]: ...
def object_info_find_vfunc(info: BaseInfo, name: str) -> typing.Optional[BaseInfo]: ...
def object_info_find_vfunc_using_interfaces(
    info: BaseInfo, name: str
) -> typing.Tuple[typing.Optional[BaseInfo], BaseInfo]: ...
def object_info_get_abstract(info: BaseInfo) -> bool: ...
def object_info_get_class_struct(info: BaseInfo) -> typing.Optional[BaseInfo]: ...
def object_info_get_constant(info: BaseInfo, n: int) -> BaseInfo: ...
def object_info_get_field(info: BaseInfo, n: int) -> BaseInfo: ...
def object_info_get_final(info: BaseInfo) -> bool: ...
def object_info_get_fundamental(info: BaseInfo) -> bool: ...
def object_info_get_get_value_function(info: BaseInfo) -> typing.Optional[str]: ...
def object_info_get_interface(info: BaseInfo, n: int) -> BaseInfo: ...
def object_info_get_method(info: BaseInfo, n: int) -> BaseInfo: ...
def object_info_get_n_constants(info: BaseInfo) -> int: ...
def object_info_get_n_fields(info: BaseInfo) -> int: ...
def object_info_get_n_interfaces(info: BaseInfo) -> int: ...
def object_info_get_n_methods(info: BaseInfo) -> int: ...
def object_info_get_n_properties(info: BaseInfo) -> int: ...
def object_info_get_n_signals(info: BaseInfo) -> int: ...
def object_info_get_n_vfuncs(info: BaseInfo) -> int: ...
def object_info_get_parent(info: BaseInfo) -> typing.Optional[BaseInfo]: ...
def object_info_get_property(info: BaseInfo, n: int) -> BaseInfo: ...
def object_info_get_ref_function(info: BaseInfo) -> typing.Optional[str]: ...
def object_info_get_set_value_function(info: BaseInfo) -> typing.Optional[str]: ...
def object_info_get_signal(info: BaseInfo, n: int) -> BaseInfo: ...
def object_info_get_type_init(info: BaseInfo) -> str: ...
def object_info_get_type_name(info: BaseInfo) -> str: ...
def object_info_get_unref_function(info: BaseInfo) -> typing.Optional[str]: ...
def object_info_get_vfunc(info: BaseInfo, n: int) -> BaseInfo: ...
def property_info_get_flags(info: BaseInfo) -> GObject.ParamFlags: ...
def property_info_get_getter(info: BaseInfo) -> typing.Optional[BaseInfo]: ...
def property_info_get_ownership_transfer(info: BaseInfo) -> Transfer: ...
def property_info_get_setter(info: BaseInfo) -> typing.Optional[BaseInfo]: ...
def property_info_get_type(info: BaseInfo) -> BaseInfo: ...
def registered_type_info_get_g_type(info: BaseInfo) -> typing.Type[typing.Any]: ...
def registered_type_info_get_type_init(info: BaseInfo) -> str: ...
def registered_type_info_get_type_name(info: BaseInfo) -> str: ...
def signal_info_get_class_closure(info: BaseInfo) -> BaseInfo: ...
def signal_info_get_flags(info: BaseInfo) -> GObject.SignalFlags: ...
def signal_info_true_stops_emit(info: BaseInfo) -> bool: ...
def struct_info_find_field(info: BaseInfo, name: str) -> BaseInfo: ...
def struct_info_find_method(info: BaseInfo, name: str) -> BaseInfo: ...
def struct_info_get_alignment(info: BaseInfo) -> int: ...
def struct_info_get_copy_function(info: BaseInfo) -> typing.Optional[str]: ...
def struct_info_get_field(info: BaseInfo, n: int) -> BaseInfo: ...
def struct_info_get_free_function(info: BaseInfo) -> typing.Optional[str]: ...
def struct_info_get_method(info: BaseInfo, n: int) -> BaseInfo: ...
def struct_info_get_n_fields(info: BaseInfo) -> int: ...
def struct_info_get_n_methods(info: BaseInfo) -> int: ...
def struct_info_get_size(info: BaseInfo) -> int: ...
def struct_info_is_foreign(info: BaseInfo) -> bool: ...
def struct_info_is_gtype_struct(info: BaseInfo) -> bool: ...
def type_info_argument_from_hash_pointer(
    info: BaseInfo, hash_pointer: None, arg: Argument
) -> None: ...
def type_info_get_array_fixed_size(info: BaseInfo) -> int: ...
def type_info_get_array_length(info: BaseInfo) -> int: ...
def type_info_get_array_type(info: BaseInfo) -> ArrayType: ...
def type_info_get_interface(info: BaseInfo) -> BaseInfo: ...
def type_info_get_param_type(info: BaseInfo, n: int) -> BaseInfo: ...
def type_info_get_storage_type(info: BaseInfo) -> TypeTag: ...
def type_info_get_tag(info: BaseInfo) -> TypeTag: ...
def type_info_hash_pointer_from_argument(info: BaseInfo, arg: Argument) -> None: ...
def type_info_is_pointer(info: BaseInfo) -> bool: ...
def type_info_is_zero_terminated(info: BaseInfo) -> bool: ...
def type_tag_argument_from_hash_pointer(
    storage_type: TypeTag, hash_pointer: None, arg: Argument
) -> None: ...
def type_tag_hash_pointer_from_argument(
    storage_type: TypeTag, arg: Argument
) -> None: ...
def type_tag_to_string(type: TypeTag) -> str: ...
def union_info_find_method(info: BaseInfo, name: str) -> BaseInfo: ...
def union_info_get_alignment(info: BaseInfo) -> int: ...
def union_info_get_copy_function(info: BaseInfo) -> typing.Optional[str]: ...
def union_info_get_discriminator(info: BaseInfo, n: int) -> BaseInfo: ...
def union_info_get_discriminator_offset(info: BaseInfo) -> int: ...
def union_info_get_discriminator_type(info: BaseInfo) -> BaseInfo: ...
def union_info_get_field(info: BaseInfo, n: int) -> BaseInfo: ...
def union_info_get_free_function(info: BaseInfo) -> typing.Optional[str]: ...
def union_info_get_method(info: BaseInfo, n: int) -> BaseInfo: ...
def union_info_get_n_fields(info: BaseInfo) -> int: ...
def union_info_get_n_methods(info: BaseInfo) -> int: ...
def union_info_get_size(info: BaseInfo) -> int: ...
def union_info_is_discriminated(info: BaseInfo) -> bool: ...
def value_info_get_value(info: BaseInfo) -> int: ...
def vfunc_info_get_address(
    info: BaseInfo, implementor_gtype: typing.Type[typing.Any]
) -> None: ...
def vfunc_info_get_flags(info: BaseInfo) -> VFuncInfoFlags: ...
def vfunc_info_get_invoker(info: BaseInfo) -> BaseInfo: ...
def vfunc_info_get_offset(info: BaseInfo) -> int: ...
def vfunc_info_get_signal(info: BaseInfo) -> BaseInfo: ...

class Argument(GObject.GPointer):
    v_boolean = ...  # FIXME Constant
    v_double = ...  # FIXME Constant
    v_float = ...  # FIXME Constant
    v_int = ...  # FIXME Constant
    v_int16 = ...  # FIXME Constant
    v_int32 = ...  # FIXME Constant
    v_int64 = ...  # FIXME Constant
    v_int8 = ...  # FIXME Constant
    v_long = ...  # FIXME Constant
    v_pointer = ...  # FIXME Constant
    v_short = ...  # FIXME Constant
    v_size = ...  # FIXME Constant
    v_ssize = ...  # FIXME Constant
    v_string = ...  # FIXME Constant
    v_uint = ...  # FIXME Constant
    v_uint16 = ...  # FIXME Constant
    v_uint32 = ...  # FIXME Constant
    v_uint64 = ...  # FIXME Constant
    v_uint8 = ...  # FIXME Constant
    v_ulong = ...  # FIXME Constant
    v_ushort = ...  # FIXME Constant

class AttributeIter(GObject.GPointer):
    """
    :Constructors:

    ::

        AttributeIter()
    """

    data: None = ...
    data2: None = ...
    data3: None = ...
    data4: None = ...

class BaseInfo(GObject.GBoxed):
    """
    :Constructors:

    ::

        BaseInfo()
    """

    dummy1: int = ...
    dummy2: int = ...
    dummy3: None = ...
    dummy4: None = ...
    dummy5: None = ...
    dummy6: int = ...
    dummy7: int = ...
    padding: list[None] = ...
    def equal(self, info2: BaseInfo) -> bool: ...
    def get_attribute(self, name: str) -> str: ...
    def get_container(self) -> BaseInfo: ...
    def get_name(self) -> str: ...
    def get_namespace(self) -> str: ...
    def get_type(self) -> InfoType: ...
    def get_typelib(self) -> Typelib: ...
    def is_deprecated(self) -> bool: ...
    def iterate_attributes(self) -> typing.Tuple[bool, AttributeIter, str, str]: ...

class Repository(GObject.Object):
    """
    :Constructors:

    ::

        Repository(**properties)

    Object GIRepository

    Signals from GObject:
      notify (GParam)
    """

    parent: GObject.Object = ...
    priv: RepositoryPrivate = ...
    @staticmethod
    def dump(arg: str) -> bool: ...
    def enumerate_versions(self, namespace_: str) -> list[str]: ...
    @staticmethod
    def error_quark() -> int: ...
    def find_by_error_domain(self, domain: int) -> BaseInfo: ...
    def find_by_gtype(self, gtype: typing.Type[typing.Any]) -> BaseInfo: ...
    def find_by_name(self, namespace_: str, name: str) -> BaseInfo: ...
    def get_c_prefix(self, namespace_: str) -> str: ...
    @staticmethod
    def get_default() -> Repository: ...
    def get_dependencies(self, namespace_: str) -> list[str]: ...
    def get_immediate_dependencies(self, namespace_: str) -> list[str]: ...
    def get_info(self, namespace_: str, index: int) -> BaseInfo: ...
    def get_loaded_namespaces(self) -> list[str]: ...
    def get_n_infos(self, namespace_: str) -> int: ...
    def get_object_gtype_interfaces(
        self, gtype: typing.Type[typing.Any]
    ) -> list[BaseInfo]: ...
    @staticmethod
    def get_option_group() -> GLib.OptionGroup: ...
    @staticmethod
    def get_search_path() -> list[str]: ...
    def get_shared_library(self, namespace_: str) -> typing.Optional[str]: ...
    def get_typelib_path(self, namespace_: str) -> str: ...
    def get_version(self, namespace_: str) -> str: ...
    def is_registered(
        self, namespace_: str, version: typing.Optional[str] = None
    ) -> bool: ...
    def load_typelib(self, typelib: Typelib, flags: RepositoryLoadFlags) -> str: ...
    @staticmethod
    def prepend_library_path(directory: str) -> None: ...
    @staticmethod
    def prepend_search_path(directory: str) -> None: ...
    def require(
        self, namespace_: str, version: typing.Optional[str], flags: RepositoryLoadFlags
    ) -> Typelib: ...
    def require_private(
        self,
        typelib_dir: str,
        namespace_: str,
        version: typing.Optional[str],
        flags: RepositoryLoadFlags,
    ) -> Typelib: ...

class RepositoryClass(GObject.GPointer):
    """
    :Constructors:

    ::

        RepositoryClass()
    """

    parent: GObject.ObjectClass = ...

class RepositoryPrivate(GObject.GPointer): ...

class Typelib(GObject.GPointer):
    def free(self) -> None: ...
    def get_namespace(self) -> str: ...
    def symbol(self, symbol_name: str, symbol: None) -> bool: ...

class UnresolvedInfo(GObject.GPointer): ...

class FieldInfoFlags(GObject.GFlags):
    READABLE = 1
    WRITABLE = 2

class FunctionInfoFlags(GObject.GFlags):
    IS_CONSTRUCTOR = 2
    IS_GETTER = 4
    IS_METHOD = 1
    IS_SETTER = 8
    THROWS = 32
    WRAPS_VFUNC = 16

class RepositoryLoadFlags(GObject.GFlags):
    IREPOSITORY_LOAD_FLAG_LAZY = 1

class VFuncInfoFlags(GObject.GFlags):
    MUST_CHAIN_UP = 1
    MUST_NOT_OVERRIDE = 4
    MUST_OVERRIDE = 2
    THROWS = 8

class ArrayType(GObject.GEnum):
    ARRAY = 1
    BYTE_ARRAY = 3
    C = 0
    PTR_ARRAY = 2

class Direction(GObject.GEnum):
    IN = 0
    INOUT = 2
    OUT = 1

class InfoType(GObject.GEnum):
    ARG = 17
    BOXED = 4
    CALLBACK = 2
    CONSTANT = 9
    ENUM = 5
    FIELD = 16
    FLAGS = 6
    FUNCTION = 1
    INTERFACE = 8
    INVALID = 0
    INVALID_0 = 10
    OBJECT = 7
    PROPERTY = 15
    SIGNAL = 13
    STRUCT = 3
    TYPE = 18
    UNION = 11
    UNRESOLVED = 19
    VALUE = 12
    VFUNC = 14

class RepositoryError(GObject.GEnum):
    LIBRARY_NOT_FOUND = 3
    NAMESPACE_MISMATCH = 1
    NAMESPACE_VERSION_CONFLICT = 2
    TYPELIB_NOT_FOUND = 0

class ScopeType(GObject.GEnum):
    ASYNC = 2
    CALL = 1
    FOREVER = 4
    INVALID = 0
    NOTIFIED = 3

class Transfer(GObject.GEnum):
    CONTAINER = 1
    EVERYTHING = 2
    NOTHING = 0

class TypeTag(GObject.GEnum):
    ARRAY = 15
    BOOLEAN = 1
    DOUBLE = 11
    ERROR = 20
    FILENAME = 14
    FLOAT = 10
    GHASH = 19
    GLIST = 17
    GSLIST = 18
    GTYPE = 12
    INT16 = 4
    INT32 = 6
    INT64 = 8
    INT8 = 2
    INTERFACE = 16
    UINT16 = 5
    UINT32 = 7
    UINT64 = 9
    UINT8 = 3
    UNICHAR = 21
    UTF8 = 13
    VOID = 0

class nvokeError(GObject.GEnum):
    ARGUMENT_MISMATCH = 2
    FAILED = 0
    SYMBOL_NOT_FOUND = 1



import typing

from gi.repository import Gio
from gi.repository import GLib
from gi.repository import GObject
from typing_extensions import Self

T = typing.TypeVar("T")

MAJOR_VERSION: int = 1
MICRO_VERSION: int = 1
MINOR_VERSION: int = 16

def error_quark() -> int: ...
def get_default_arch() -> str: ...
def get_supported_arches() -> list[str]: ...
def get_system_installations(
    cancellable: typing.Optional[Gio.Cancellable] = None,
) -> list[Installation]: ...
def portal_error_quark() -> int: ...
def transaction_operation_type_to_string(kind: TransactionOperationType) -> str: ...

class BundleRef(Ref):
    """
    :Constructors:

    ::

        BundleRef(**properties)
        new(file:Gio.File) -> Flatpak.BundleRef

    Object FlatpakBundleRef

    Properties from FlatpakBundleRef:
      file -> GFile:


    Properties from FlatpakRef:
      name -> gchararray: Name
        The name of the application or runtime
      arch -> gchararray: Architecture
        The architecture of the application or runtime
      branch -> gchararray: Branch
        The branch of the application or runtime
      commit -> gchararray: Commit
        The commit
      kind -> FlatpakRefKind: Kind
        The kind of artifact
      collection-id -> gchararray: Collection ID
        The collection ID

    Signals from GObject:
      notify (GParam)
    """
    class Props(Ref.Props):
        file: Gio.File
        arch: str
        branch: str
        collection_id: str
        commit: str
        kind: RefKind
        name: str

    props: Props = ...
    parent: Ref = ...
    def __init__(
        self,
        file: Gio.File = ...,
        arch: str = ...,
        branch: str = ...,
        collection_id: str = ...,
        commit: str = ...,
        kind: RefKind = ...,
        name: str = ...,
    ) -> None: ...
    def get_appstream(self) -> GLib.Bytes: ...
    def get_file(self) -> Gio.File: ...
    def get_icon(self, size: int) -> GLib.Bytes: ...
    def get_installed_size(self) -> int: ...
    def get_metadata(self) -> GLib.Bytes: ...
    def get_origin(self) -> str: ...
    def get_runtime_repo_url(self) -> str: ...
    @classmethod
    def new(cls, file: Gio.File) -> BundleRef: ...

class BundleRefClass(GObject.GPointer):
    """
    :Constructors:

    ::

        BundleRefClass()
    """

    parent_class: RefClass = ...

class Installation(GObject.Object):
    """
    :Constructors:

    ::

        Installation(**properties)
        new_for_path(path:Gio.File, user:bool, cancellable:Gio.Cancellable=None) -> Flatpak.Installation
        new_system(cancellable:Gio.Cancellable=None) -> Flatpak.Installation
        new_system_with_id(id:str=None, cancellable:Gio.Cancellable=None) -> Flatpak.Installation
        new_user(cancellable:Gio.Cancellable=None) -> Flatpak.Installation

    Object FlatpakInstallation

    Signals from GObject:
      notify (GParam)
    """

    parent: GObject.Object = ...
    def add_remote(
        self,
        remote: Remote,
        if_needed: bool,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> bool: ...
    def cleanup_local_refs_sync(
        self, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> bool: ...
    def create_monitor(
        self, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> Gio.FileMonitor: ...
    def drop_caches(
        self, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> bool: ...
    def fetch_remote_metadata_sync(
        self,
        remote_name: str,
        ref: Ref,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> GLib.Bytes: ...
    def fetch_remote_ref_sync(
        self,
        remote_name: str,
        kind: RefKind,
        name: str,
        arch: typing.Optional[str] = None,
        branch: typing.Optional[str] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> RemoteRef: ...
    def fetch_remote_ref_sync_full(
        self,
        remote_name: str,
        kind: RefKind,
        name: str,
        arch: typing.Optional[str],
        branch: typing.Optional[str],
        flags: QueryFlags,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> RemoteRef: ...
    def fetch_remote_size_sync(
        self,
        remote_name: str,
        ref: Ref,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> typing.Tuple[bool, int, int]: ...
    def get_config(
        self, key: str, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> str: ...
    def get_current_installed_app(
        self, name: str, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> InstalledRef: ...
    def get_default_languages(self) -> list[str]: ...
    def get_default_locales(self) -> list[str]: ...
    def get_display_name(self) -> str: ...
    def get_id(self) -> str: ...
    def get_installed_ref(
        self,
        kind: RefKind,
        name: str,
        arch: typing.Optional[str] = None,
        branch: typing.Optional[str] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> InstalledRef: ...
    def get_is_user(self) -> bool: ...
    def get_min_free_space_bytes(self) -> typing.Tuple[bool, int]: ...
    def get_no_interaction(self) -> bool: ...
    def get_path(self) -> Gio.File: ...
    def get_priority(self) -> int: ...
    def get_remote_by_name(
        self, name: str, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> Remote: ...
    def get_storage_type(self) -> StorageType: ...
    def install(
        self,
        remote_name: str,
        kind: RefKind,
        name: str,
        arch: typing.Optional[str] = None,
        branch: typing.Optional[str] = None,
        progress: typing.Optional[typing.Callable[..., None]] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
        *progress_data: typing.Any,
    ) -> InstalledRef: ...
    def install_bundle(
        self,
        file: Gio.File,
        progress: typing.Optional[typing.Callable[..., None]] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
        *progress_data: typing.Any,
    ) -> InstalledRef: ...
    def install_full(
        self,
        flags: InstallFlags,
        remote_name: str,
        kind: RefKind,
        name: str,
        arch: typing.Optional[str] = None,
        branch: typing.Optional[str] = None,
        subpaths: typing.Optional[typing.Sequence[str]] = None,
        progress: typing.Optional[typing.Callable[..., None]] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
        *progress_data: typing.Any,
    ) -> InstalledRef: ...
    def install_ref_file(
        self,
        ref_file_data: GLib.Bytes,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> RemoteRef: ...
    def launch(
        self,
        name: str,
        arch: typing.Optional[str] = None,
        branch: typing.Optional[str] = None,
        commit: typing.Optional[str] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> bool: ...
    def launch_full(
        self,
        flags: LaunchFlags,
        name: str,
        arch: typing.Optional[str] = None,
        branch: typing.Optional[str] = None,
        commit: typing.Optional[str] = None,
        instance_out: typing.Optional[Instance] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> bool: ...
    def list_installed_refs(
        self, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> list[InstalledRef]: ...
    def list_installed_refs_by_kind(
        self, kind: RefKind, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> list[InstalledRef]: ...
    def list_installed_refs_for_update(
        self, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> list[InstalledRef]: ...
    def list_installed_related_refs_sync(
        self,
        remote_name: str,
        ref: str,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> list[RelatedRef]: ...
    def list_pinned_refs(
        self,
        arch: typing.Optional[str] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> list[InstalledRef]: ...
    def list_remote_refs_sync(
        self, remote_or_uri: str, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> list[RemoteRef]: ...
    def list_remote_refs_sync_full(
        self,
        remote_or_uri: str,
        flags: QueryFlags,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> list[RemoteRef]: ...
    def list_remote_related_refs_for_installed_sync(
        self,
        remote_name: str,
        ref: str,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> list[RelatedRef]: ...
    def list_remote_related_refs_sync(
        self,
        remote_name: str,
        ref: str,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> list[RelatedRef]: ...
    def list_remotes(
        self, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> list[Remote]: ...
    def list_remotes_by_type(
        self,
        types: typing.Sequence[RemoteType],
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> list[Remote]: ...
    def list_unused_refs(
        self,
        arch: typing.Optional[str] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> list[InstalledRef]: ...
    def list_unused_refs_with_options(
        self,
        arch: typing.Optional[str] = None,
        metadata_injection: typing.Optional[dict[None, None]] = None,
        options: typing.Optional[GLib.Variant] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> list[InstalledRef]: ...
    def load_app_overrides(
        self, app_id: str, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> str: ...
    def modify_remote(
        self, remote: Remote, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> bool: ...
    @classmethod
    def new_for_path(
        cls,
        path: Gio.File,
        user: bool,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> Installation: ...
    @classmethod
    def new_system(
        cls, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> Installation: ...
    @classmethod
    def new_system_with_id(
        cls,
        id: typing.Optional[str] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> Installation: ...
    @classmethod
    def new_user(
        cls, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> Installation: ...
    def prune_local_repo(
        self, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> bool: ...
    def remove_local_ref_sync(
        self,
        remote_name: str,
        ref: str,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> bool: ...
    def remove_remote(
        self, name: str, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> bool: ...
    def run_triggers(
        self, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> bool: ...
    def set_config_sync(
        self, key: str, value: str, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> bool: ...
    def set_no_interaction(self, no_interaction: bool) -> None: ...
    def uninstall(
        self,
        kind: RefKind,
        name: str,
        arch: typing.Optional[str] = None,
        branch: typing.Optional[str] = None,
        progress: typing.Optional[typing.Callable[..., None]] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
        *progress_data: typing.Any,
    ) -> bool: ...
    def uninstall_full(
        self,
        flags: UninstallFlags,
        kind: RefKind,
        name: str,
        arch: typing.Optional[str] = None,
        branch: typing.Optional[str] = None,
        progress: typing.Optional[typing.Callable[..., None]] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
        *progress_data: typing.Any,
    ) -> bool: ...
    def update(
        self,
        flags: UpdateFlags,
        kind: RefKind,
        name: str,
        arch: typing.Optional[str] = None,
        branch: typing.Optional[str] = None,
        progress: typing.Optional[typing.Callable[..., None]] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
        *progress_data: typing.Any,
    ) -> InstalledRef: ...
    def update_appstream_full_sync(
        self,
        remote_name: str,
        arch: typing.Optional[str] = None,
        progress: typing.Optional[typing.Callable[..., None]] = None,
        out_changed: typing.Optional[bool] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
        *progress_data: typing.Any,
    ) -> bool: ...
    def update_appstream_sync(
        self,
        remote_name: str,
        arch: typing.Optional[str] = None,
        out_changed: typing.Optional[bool] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> bool: ...
    def update_full(
        self,
        flags: UpdateFlags,
        kind: RefKind,
        name: str,
        arch: typing.Optional[str] = None,
        branch: typing.Optional[str] = None,
        subpaths: typing.Optional[typing.Sequence[str]] = None,
        progress: typing.Optional[typing.Callable[..., None]] = None,
        cancellable: typing.Optional[Gio.Cancellable] = None,
        *progress_data: typing.Any,
    ) -> InstalledRef: ...
    def update_remote_sync(
        self, name: str, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> bool: ...

class InstallationClass(GObject.GPointer):
    """
    :Constructors:

    ::

        InstallationClass()
    """

    parent_class: GObject.ObjectClass = ...

class InstalledRef(Ref):
    """
    :Constructors:

    ::

        InstalledRef(**properties)

    Object FlatpakInstalledRef

    Properties from FlatpakInstalledRef:
      is-current -> gboolean: Is Current
        Whether the application is current
      origin -> gchararray: Origin
        The origin
      latest-commit -> gchararray: Latest Commit
        The latest commit
      deploy-dir -> gchararray: Deploy Dir
        Where the application is installed
      installed-size -> guint64: Installed Size
        The installed size of the application
      subpaths -> GStrv: Subpaths
        The subpaths for a partially installed ref
      end-of-life -> gchararray: End of life
        The reason for the ref to be end of life
      end-of-life-rebase -> gchararray: End of life rebase
        The new ref for the end-of-lifed ref
      appdata-name -> gchararray: Appdata Name
        The localized name field from the appdata
      appdata-summary -> gchararray: Appdata Summary
        The localized summary field from the appdata
      appdata-version -> gchararray: Appdata Version
        The default version field from the appdata
      appdata-license -> gchararray: Appdata License
        The license from the appdata
      appdata-content-rating-type -> gchararray: Appdata Content Rating Type
        The type of the content rating data from the appdata
      appdata-content-rating -> GHashTable: Appdata Content Rating
        The content rating data from the appdata

    Properties from FlatpakRef:
      name -> gchararray: Name
        The name of the application or runtime
      arch -> gchararray: Architecture
        The architecture of the application or runtime
      branch -> gchararray: Branch
        The branch of the application or runtime
      commit -> gchararray: Commit
        The commit
      kind -> FlatpakRefKind: Kind
        The kind of artifact
      collection-id -> gchararray: Collection ID
        The collection ID

    Signals from GObject:
      notify (GParam)
    """
    class Props(Ref.Props):
        appdata_content_rating: typing.Optional[dict[None, None]]
        appdata_content_rating_type: typing.Optional[str]
        appdata_license: str
        appdata_name: str
        appdata_summary: str
        appdata_version: str
        deploy_dir: str
        end_of_life: str
        end_of_life_rebase: str
        installed_size: int
        is_current: bool
        latest_commit: typing.Optional[str]
        origin: str
        subpaths: list[str]
        arch: str
        branch: str
        collection_id: str
        commit: str
        kind: RefKind
        name: str

    props: Props = ...
    parent: Ref = ...
    def __init__(
        self,
        appdata_content_rating: dict[None, None] = ...,
        appdata_content_rating_type: str = ...,
        appdata_license: str = ...,
        appdata_name: str = ...,
        appdata_summary: str = ...,
        appdata_version: str = ...,
        deploy_dir: str = ...,
        end_of_life: str = ...,
        end_of_life_rebase: str = ...,
        installed_size: int = ...,
        is_current: bool = ...,
        latest_commit: str = ...,
        origin: str = ...,
        subpaths: typing.Sequence[str] = ...,
        arch: str = ...,
        branch: str = ...,
        collection_id: str = ...,
        commit: str = ...,
        kind: RefKind = ...,
        name: str = ...,
    ) -> None: ...
    def get_appdata_content_rating(self) -> typing.Optional[dict[str, str]]: ...
    def get_appdata_content_rating_type(self) -> typing.Optional[str]: ...
    def get_appdata_license(self) -> str: ...
    def get_appdata_name(self) -> str: ...
    def get_appdata_summary(self) -> str: ...
    def get_appdata_version(self) -> str: ...
    def get_deploy_dir(self) -> str: ...
    def get_eol(self) -> str: ...
    def get_eol_rebase(self) -> str: ...
    def get_installed_size(self) -> int: ...
    def get_is_current(self) -> bool: ...
    def get_latest_commit(self) -> typing.Optional[str]: ...
    def get_origin(self) -> str: ...
    def get_subpaths(self) -> list[str]: ...
    def load_appdata(
        self, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> GLib.Bytes: ...
    def load_metadata(
        self, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> GLib.Bytes: ...

class InstalledRefClass(GObject.GPointer):
    """
    :Constructors:

    ::

        InstalledRefClass()
    """

    parent_class: RefClass = ...

class Instance(GObject.Object):
    """
    :Constructors:

    ::

        Instance(**properties)

    Object FlatpakInstance

    Signals from GObject:
      notify (GParam)
    """

    parent: GObject.Object = ...
    @staticmethod
    def get_all() -> list[Instance]: ...
    def get_app(self) -> typing.Optional[str]: ...
    def get_arch(self) -> str: ...
    def get_branch(self) -> str: ...
    def get_child_pid(self) -> int: ...
    def get_commit(self) -> str: ...
    def get_id(self) -> str: ...
    def get_info(self) -> GLib.KeyFile: ...
    def get_pid(self) -> int: ...
    def get_runtime(self) -> str: ...
    def get_runtime_commit(self) -> str: ...
    def is_running(self) -> bool: ...

class InstanceClass(GObject.GPointer):
    """
    :Constructors:

    ::

        InstanceClass()
    """

    parent_class: GObject.ObjectClass = ...

class Ref(GObject.Object):
    """
    :Constructors:

    ::

        Ref(**properties)

    Object FlatpakRef

    Properties from FlatpakRef:
      name -> gchararray: Name
        The name of the application or runtime
      arch -> gchararray: Architecture
        The architecture of the application or runtime
      branch -> gchararray: Branch
        The branch of the application or runtime
      commit -> gchararray: Commit
        The commit
      kind -> FlatpakRefKind: Kind
        The kind of artifact
      collection-id -> gchararray: Collection ID
        The collection ID

    Signals from GObject:
      notify (GParam)
    """
    class Props(GObject.Object.Props):
        arch: str
        branch: str
        collection_id: str
        commit: str
        kind: RefKind
        name: str

    props: Props = ...
    parent: GObject.Object = ...
    def __init__(
        self,
        arch: str = ...,
        branch: str = ...,
        collection_id: str = ...,
        commit: str = ...,
        kind: RefKind = ...,
        name: str = ...,
    ) -> None: ...
    def format_ref(self) -> str: ...
    def format_ref_cached(self) -> str: ...
    def get_arch(self) -> str: ...
    def get_branch(self) -> str: ...
    def get_collection_id(self) -> str: ...
    def get_commit(self) -> str: ...
    def get_kind(self) -> RefKind: ...
    def get_name(self) -> str: ...
    @staticmethod
    def parse(ref: str) -> Ref: ...

class RefClass(GObject.GPointer):
    """
    :Constructors:

    ::

        RefClass()
    """

    parent_class: GObject.ObjectClass = ...

class RelatedRef(Ref):
    """
    :Constructors:

    ::

        RelatedRef(**properties)

    Object FlatpakRelatedRef

    Properties from FlatpakRelatedRef:
      subpaths -> GStrv: Subpaths
        The subpaths for a partially installed ref
      should-download -> gboolean: Should download
        Whether to auto-download the ref with the main ref
      should-delete -> gboolean: Should delete
        Whether to auto-delete the ref with the main ref
      should-autoprune -> gboolean: Should autoprune
        Whether to delete when pruning unused refs

    Properties from FlatpakRef:
      name -> gchararray: Name
        The name of the application or runtime
      arch -> gchararray: Architecture
        The architecture of the application or runtime
      branch -> gchararray: Branch
        The branch of the application or runtime
      commit -> gchararray: Commit
        The commit
      kind -> FlatpakRefKind: Kind
        The kind of artifact
      collection-id -> gchararray: Collection ID
        The collection ID

    Signals from GObject:
      notify (GParam)
    """
    class Props(Ref.Props):
        should_autoprune: bool
        should_delete: bool
        should_download: bool
        subpaths: list[str]
        arch: str
        branch: str
        collection_id: str
        commit: str
        kind: RefKind
        name: str

    props: Props = ...
    parent: Ref = ...
    def __init__(
        self,
        should_autoprune: bool = ...,
        should_delete: bool = ...,
        should_download: bool = ...,
        subpaths: typing.Sequence[str] = ...,
        arch: str = ...,
        branch: str = ...,
        collection_id: str = ...,
        commit: str = ...,
        kind: RefKind = ...,
        name: str = ...,
    ) -> None: ...
    def get_subpaths(self) -> list[str]: ...
    def should_autoprune(self) -> bool: ...
    def should_delete(self) -> bool: ...
    def should_download(self) -> bool: ...

class RelatedRefClass(GObject.GPointer):
    """
    :Constructors:

    ::

        RelatedRefClass()
    """

    parent_class: RefClass = ...

class Remote(GObject.Object):
    """
    :Constructors:

    ::

        Remote(**properties)
        new(name:str) -> Flatpak.Remote
        new_from_file(name:str, data:GLib.Bytes) -> Flatpak.Remote

    Object FlatpakRemote

    Properties from FlatpakRemote:
      name -> gchararray: Name
        The name of the remote
      type -> FlatpakRemoteType: Type
        The type of the remote

    Signals from GObject:
      notify (GParam)
    """
    class Props(GObject.Object.Props):
        name: str
        type: RemoteType

    props: Props = ...
    parent: GObject.Object = ...
    def __init__(self, name: str = ..., type: RemoteType = ...) -> None: ...
    def get_appstream_dir(self, arch: typing.Optional[str] = None) -> Gio.File: ...
    def get_appstream_timestamp(
        self, arch: typing.Optional[str] = None
    ) -> Gio.File: ...
    def get_collection_id(self) -> typing.Optional[str]: ...
    def get_comment(self) -> str: ...
    def get_default_branch(self) -> str: ...
    def get_description(self) -> str: ...
    def get_disabled(self) -> bool: ...
    def get_filter(self) -> str: ...
    def get_gpg_verify(self) -> bool: ...
    def get_homepage(self) -> str: ...
    def get_icon(self) -> str: ...
    def get_main_ref(self) -> str: ...
    def get_name(self) -> str: ...
    def get_nodeps(self) -> bool: ...
    def get_noenumerate(self) -> bool: ...
    def get_prio(self) -> int: ...
    def get_remote_type(self) -> RemoteType: ...
    def get_title(self) -> str: ...
    def get_url(self) -> str: ...
    @classmethod
    def new(cls, name: str) -> Remote: ...
    @classmethod
    def new_from_file(cls, name: str, data: GLib.Bytes) -> Remote: ...
    def set_collection_id(self, collection_id: typing.Optional[str] = None) -> None: ...
    def set_comment(self, comment: str) -> None: ...
    def set_default_branch(self, default_branch: str) -> None: ...
    def set_description(self, description: str) -> None: ...
    def set_disabled(self, disabled: bool) -> None: ...
    def set_filter(self, filter_path: str) -> None: ...
    def set_gpg_key(self, gpg_key: GLib.Bytes) -> None: ...
    def set_gpg_verify(self, gpg_verify: bool) -> None: ...
    def set_homepage(self, homepage: str) -> None: ...
    def set_icon(self, icon: str) -> None: ...
    def set_main_ref(self, main_ref: str) -> None: ...
    def set_nodeps(self, nodeps: bool) -> None: ...
    def set_noenumerate(self, noenumerate: bool) -> None: ...
    def set_prio(self, prio: int) -> None: ...
    def set_title(self, title: str) -> None: ...
    def set_url(self, url: str) -> None: ...

class RemoteClass(GObject.GPointer):
    """
    :Constructors:

    ::

        RemoteClass()
    """

    parent_class: GObject.ObjectClass = ...

class RemoteRef(Ref):
    """
    :Constructors:

    ::

        RemoteRef(**properties)

    Object FlatpakRemoteRef

    Properties from FlatpakRemoteRef:
      remote-name -> gchararray: Remote Name
        The name of the remote
      installed-size -> guint64: Installed Size
        The installed size of the application
      download-size -> guint64: Download Size
        The download size of the application
      metadata -> GBytes: Metadata
        The metadata info for the application
      end-of-life -> gchararray: End of life
        The reason for the ref to be end of life
      end-of-life-rebase -> gchararray: End of life rebase
        The new ref for the end of lifeed ref

    Properties from FlatpakRef:
      name -> gchararray: Name
        The name of the application or runtime
      arch -> gchararray: Architecture
        The architecture of the application or runtime
      branch -> gchararray: Branch
        The branch of the application or runtime
      commit -> gchararray: Commit
        The commit
      kind -> FlatpakRefKind: Kind
        The kind of artifact
      collection-id -> gchararray: Collection ID
        The collection ID

    Signals from GObject:
      notify (GParam)
    """
    class Props(Ref.Props):
        download_size: int
        end_of_life: str
        end_of_life_rebase: str
        installed_size: int
        metadata: typing.Optional[GLib.Bytes]
        remote_name: str
        arch: str
        branch: str
        collection_id: str
        commit: str
        kind: RefKind
        name: str

    props: Props = ...
    parent: Ref = ...
    def __init__(
        self,
        download_size: int = ...,
        end_of_life: str = ...,
        end_of_life_rebase: str = ...,
        installed_size: int = ...,
        metadata: GLib.Bytes = ...,
        remote_name: str = ...,
        arch: str = ...,
        branch: str = ...,
        collection_id: str = ...,
        commit: str = ...,
        kind: RefKind = ...,
        name: str = ...,
    ) -> None: ...
    def get_download_size(self) -> int: ...
    def get_eol(self) -> str: ...
    def get_eol_rebase(self) -> str: ...
    def get_installed_size(self) -> int: ...
    def get_metadata(self) -> typing.Optional[GLib.Bytes]: ...
    def get_remote_name(self) -> str: ...

class RemoteRefClass(GObject.GPointer):
    """
    :Constructors:

    ::

        RemoteRefClass()
    """

    parent_class: RefClass = ...

class Transaction(GObject.Object, Gio.Initable):
    """
    :Constructors:

    ::

        Transaction(**properties)
        new_for_installation(installation:Flatpak.Installation, cancellable:Gio.Cancellable=None) -> Flatpak.Transaction

    Object FlatpakTransaction

    Signals from FlatpakTransaction:
      new-operation (FlatpakTransactionOperation, FlatpakTransactionProgress)
      operation-error (FlatpakTransactionOperation, GError, gint) -> gboolean
      operation-done (FlatpakTransactionOperation, gchararray, gint)
      choose-remote-for-ref (gchararray, gchararray, GStrv) -> gint
      end-of-lifed (gchararray, gchararray, gchararray)
      end-of-lifed-with-rebase (gchararray, gchararray, gchararray, gchararray, GStrv) -> gboolean
      ready () -> gboolean
      ready-pre-auth () -> gboolean
      add-new-remote (gint, gchararray, gchararray, gchararray) -> gboolean
      install-authenticator (gchararray, gchararray)
      webflow-start (gchararray, gchararray, GVariant, gint) -> gboolean
      webflow-done (GVariant, gint)
      basic-auth-start (gchararray, gchararray, GVariant, gint) -> gboolean

    Properties from FlatpakTransaction:
      installation -> FlatpakInstallation: Installation
        The installation instance
      no-interaction -> gboolean: No Interaction
        The installation instance

    Signals from GObject:
      notify (GParam)
    """
    class Props(GObject.Object.Props):
        installation: Installation
        no_interaction: bool

    props: Props = ...
    parent_instance: GObject.Object = ...
    def __init__(
        self, installation: Installation = ..., no_interaction: bool = ...
    ) -> None: ...
    def abort_webflow(self, id: int) -> None: ...
    def add_default_dependency_sources(self) -> None: ...
    def add_dependency_source(self, installation: Installation) -> None: ...
    def add_install(
        self,
        remote: str,
        ref: str,
        subpaths: typing.Optional[typing.Sequence[str]] = None,
    ) -> bool: ...
    def add_install_bundle(
        self, file: Gio.File, gpg_data: typing.Optional[GLib.Bytes] = None
    ) -> bool: ...
    def add_install_flatpakref(self, flatpakref_data: GLib.Bytes) -> bool: ...
    def add_rebase(
        self,
        remote: str,
        ref: str,
        subpaths: typing.Optional[str] = None,
        previous_ids: typing.Optional[typing.Sequence[str]] = None,
    ) -> bool: ...
    def add_rebase_and_uninstall(
        self,
        remote: str,
        new_ref: str,
        old_ref: str,
        subpaths: typing.Optional[str] = None,
        previous_ids: typing.Optional[typing.Sequence[str]] = None,
    ) -> bool: ...
    def add_sideload_repo(self, path: str) -> None: ...
    def add_uninstall(self, ref: str) -> bool: ...
    def add_update(
        self,
        ref: str,
        subpaths: typing.Optional[typing.Sequence[str]] = None,
        commit: typing.Optional[str] = None,
    ) -> bool: ...
    def complete_basic_auth(
        self, id: int, user: str, password: str, options: GLib.Variant
    ) -> None: ...
    def do_add_new_remote(
        self, reason: TransactionRemoteReason, from_id: str, remote_name: str, url: str
    ) -> bool: ...
    def do_basic_auth_start(
        self, remote: str, realm: str, options: GLib.Variant, id: int
    ) -> bool: ...
    def do_choose_remote_for_ref(
        self, for_ref: str, runtime_ref: str, remotes: str
    ) -> int: ...
    def do_end_of_lifed(self, ref: str, reason: str, rebase: str) -> None: ...
    def do_end_of_lifed_with_rebase(
        self, remote: str, ref: str, reason: str, rebased_to_ref: str, previous_ids: str
    ) -> bool: ...
    def do_install_authenticator(self, remote: str, authenticator_ref: str) -> None: ...
    def do_new_operation(
        self, operation: TransactionOperation, progress: TransactionProgress
    ) -> None: ...
    def do_operation_done(
        self, operation: TransactionOperation, commit: str, details: TransactionResult
    ) -> None: ...
    def do_operation_error(
        self,
        operation: TransactionOperation,
        error: GLib.Error,
        detail: TransactionErrorDetails,
    ) -> bool: ...
    def do_ready(self) -> bool: ...
    def do_ready_pre_auth(self) -> bool: ...
    def do_run(self, cancellable: typing.Optional[Gio.Cancellable] = None) -> bool: ...
    def do_webflow_done(self, options: GLib.Variant, id: int) -> None: ...
    def do_webflow_start(
        self, remote: str, url: str, options: GLib.Variant, id: int
    ) -> bool: ...
    def get_auto_install_debug(self) -> bool: ...
    def get_auto_install_sdk(self) -> bool: ...
    def get_current_operation(self) -> TransactionOperation: ...
    def get_include_unused_uninstall_ops(self) -> bool: ...
    def get_installation(self) -> Installation: ...
    def get_no_deploy(self) -> bool: ...
    def get_no_interaction(self) -> bool: ...
    def get_no_pull(self) -> bool: ...
    def get_operation_for_ref(
        self, remote: typing.Optional[str], ref: str
    ) -> TransactionOperation: ...
    def get_operations(self) -> list[TransactionOperation]: ...
    def get_parent_window(self) -> str: ...
    def is_empty(self) -> bool: ...
    @classmethod
    def new_for_installation(
        cls,
        installation: Installation,
        cancellable: typing.Optional[Gio.Cancellable] = None,
    ) -> Transaction: ...
    def run(self, cancellable: typing.Optional[Gio.Cancellable] = None) -> bool: ...
    def set_auto_install_debug(self, auto_install_debug: bool) -> None: ...
    def set_auto_install_sdk(self, auto_install_sdk: bool) -> None: ...
    def set_default_arch(self, arch: str) -> None: ...
    def set_disable_auto_pin(self, disable_pin: bool) -> None: ...
    def set_disable_dependencies(self, disable_dependencies: bool) -> None: ...
    def set_disable_prune(self, disable_prune: bool) -> None: ...
    def set_disable_related(self, disable_related: bool) -> None: ...
    def set_disable_static_deltas(self, disable_static_deltas: bool) -> None: ...
    def set_force_uninstall(self, force_uninstall: bool) -> None: ...
    def set_include_unused_uninstall_ops(
        self, include_unused_uninstall_ops: bool
    ) -> None: ...
    def set_no_deploy(self, no_deploy: bool) -> None: ...
    def set_no_interaction(self, no_interaction: bool) -> None: ...
    def set_no_pull(self, no_pull: bool) -> None: ...
    def set_parent_window(self, parent_window: str) -> None: ...
    def set_reinstall(self, reinstall: bool) -> None: ...

class TransactionClass(GObject.GPointer):
    """
    :Constructors:

    ::

        TransactionClass()
    """

    parent_class: GObject.ObjectClass = ...
    new_operation: typing.Callable[
        [Transaction, TransactionOperation, TransactionProgress], None
    ] = ...
    operation_done: typing.Callable[
        [Transaction, TransactionOperation, str, TransactionResult], None
    ] = ...
    operation_error: typing.Callable[
        [Transaction, TransactionOperation, GLib.Error, TransactionErrorDetails], bool
    ] = ...
    choose_remote_for_ref: typing.Callable[[Transaction, str, str, str], int] = ...
    end_of_lifed: typing.Callable[[Transaction, str, str, str], None] = ...
    ready: typing.Callable[[Transaction], bool] = ...
    add_new_remote: typing.Callable[
        [Transaction, TransactionRemoteReason, str, str, str], bool
    ] = ...
    run: typing.Callable[[Transaction, typing.Optional[Gio.Cancellable]], bool] = ...
    end_of_lifed_with_rebase: typing.Callable[
        [Transaction, str, str, str, str, str], bool
    ] = ...
    webflow_start: typing.Callable[
        [Transaction, str, str, GLib.Variant, int], bool
    ] = ...
    webflow_done: typing.Callable[[Transaction, GLib.Variant, int], None] = ...
    basic_auth_start: typing.Callable[
        [Transaction, str, str, GLib.Variant, int], bool
    ] = ...
    install_authenticator: typing.Callable[[Transaction, str, str], None] = ...
    ready_pre_auth: typing.Callable[[Transaction], bool] = ...
    padding: list[None] = ...

class TransactionOperation(GObject.Object):
    """
    :Constructors:

    ::

        TransactionOperation(**properties)

    Object FlatpakTransactionOperation

    Signals from GObject:
      notify (GParam)
    """
    def get_bundle_path(self) -> Gio.File: ...
    def get_commit(self) -> str: ...
    def get_download_size(self) -> int: ...
    def get_installed_size(self) -> int: ...
    def get_is_skipped(self) -> bool: ...
    def get_metadata(self) -> GLib.KeyFile: ...
    def get_old_metadata(self) -> GLib.KeyFile: ...
    def get_operation_type(self) -> TransactionOperationType: ...
    def get_ref(self) -> str: ...
    def get_related_to_ops(self) -> typing.Optional[list[TransactionOperation]]: ...
    def get_remote(self) -> str: ...
    def get_requires_authentication(self) -> bool: ...
    def get_subpaths(self) -> list[str]: ...

class TransactionOperationClass(GObject.GPointer):
    """
    :Constructors:

    ::

        TransactionOperationClass()
    """

    parent_class: GObject.ObjectClass = ...

class TransactionProgress(GObject.Object):
    """
    :Constructors:

    ::

        TransactionProgress(**properties)

    Object FlatpakTransactionProgress

    Signals from FlatpakTransactionProgress:
      changed ()

    Signals from GObject:
      notify (GParam)
    """
    def get_bytes_transferred(self) -> int: ...
    def get_is_estimating(self) -> bool: ...
    def get_progress(self) -> int: ...
    def get_start_time(self) -> int: ...
    def get_status(self) -> str: ...
    def set_update_frequency(self, update_interval: int) -> None: ...

class TransactionProgressClass(GObject.GPointer):
    """
    :Constructors:

    ::

        TransactionProgressClass()
    """

    parent_class: GObject.ObjectClass = ...

class InstallFlags(GObject.GFlags):
    NONE = 0
    NO_DEPLOY = 4
    NO_PULL = 8
    NO_STATIC_DELTAS = 1
    NO_TRIGGERS = 16

class LaunchFlags(GObject.GFlags):
    DO_NOT_REAP = 1
    NONE = 0

class QueryFlags(GObject.GFlags):
    ALL_ARCHES = 4
    NONE = 0
    ONLY_CACHED = 1
    ONLY_SIDELOADED = 2

class TransactionErrorDetails(GObject.GFlags):
    FATAL = 1

class TransactionResult(GObject.GFlags):
    CHANGE = 1

class UninstallFlags(GObject.GFlags):
    NONE = 0
    NO_PRUNE = 1
    NO_TRIGGERS = 2

class UpdateFlags(GObject.GFlags):
    NONE = 0
    NO_DEPLOY = 1
    NO_PRUNE = 8
    NO_PULL = 2
    NO_STATIC_DELTAS = 4
    NO_TRIGGERS = 16

class Error(GObject.GEnum):
    ABORTED = 4
    ALREADY_INSTALLED = 0
    AUTHENTICATION_FAILED = 23
    DIFFERENT_REMOTE = 3
    DOWNGRADE = 9
    EXPORT_FAILED = 14
    INVALID_DATA = 11
    INVALID_NAME = 17
    INVALID_REF = 10
    NEED_NEW_FLATPAK = 6
    NOT_AUTHORIZED = 24
    NOT_CACHED = 20
    NOT_INSTALLED = 1
    ONLY_PULLED = 2
    OUT_OF_SPACE = 18
    PERMISSION_DENIED = 22
    REF_NOT_FOUND = 21
    REMOTE_NOT_FOUND = 7
    REMOTE_USED = 15
    RUNTIME_NOT_FOUND = 8
    RUNTIME_USED = 16
    SETUP_FAILED = 13
    SKIPPED = 5
    UNTRUSTED = 12
    WRONG_USER = 19
    @staticmethod
    def quark() -> int: ...

class PortalError(GObject.GEnum):
    CANCELLED = 5
    EXISTS = 3
    FAILED = 0
    INVALID_ARGUMENT = 1
    NOT_ALLOWED = 4
    NOT_FOUND = 2
    WINDOW_DESTROYED = 6
    @staticmethod
    def quark() -> int: ...

class RefKind(GObject.GEnum):
    APP = 0
    RUNTIME = 1

class RemoteType(GObject.GEnum):
    LAN = 2
    STATIC = 0
    USB = 1

class StorageType(GObject.GEnum):
    DEFAULT = 0
    HARD_DISK = 1
    MMC = 3
    NETWORK = 4
    SDCARD = 2

class TransactionOperationType(GObject.GEnum):
    INSTALL = 0
    INSTALL_BUNDLE = 2
    LAST_TYPE = 4
    UNINSTALL = 3
    UPDATE = 1
    @staticmethod
    def to_string(kind: TransactionOperationType) -> str: ...

class TransactionRemoteReason(GObject.GEnum):
    GENERIC_REPO = 0
    RUNTIME_DEPS = 1



import typing

from gi.repository import Gio
from gi.repository import GObject

T = typing.TypeVar("T")

_lock = ...  # FIXME Constant
_namespace: str = "GioWin32"
_version: str = "2.0"

def registry_settings_backend_new(
    registry_key: typing.Optional[str] = None,
) -> Gio.SettingsBackend: ...

class InputStream(Gio.InputStream):
    """
    :Constructors:

    ::

        InputStream(**properties)
        new(handle=None, close_handle:bool) -> Gio.InputStream

    Object GWin32InputStream

    Properties from GWin32InputStream:
      handle -> gpointer: handle
      close-handle -> gboolean: close-handle

    Signals from GObject:
      notify (GParam)
    """

    parent_instance: Gio.InputStream = ...
    priv: InputStreamPrivate = ...
    @staticmethod
    def get_close_handle(stream: InputStream) -> bool: ...
    @staticmethod
    def get_handle(stream: InputStream) -> None: ...
    def new(
        handle: typing.Any, close_handle: bool
    ) -> InputStream: ...  # FIXME Function
    @staticmethod
    def set_close_handle(stream: InputStream, close_handle: bool) -> None: ...

class InputStreamClass(GObject.GPointer):
    """
    :Constructors:

    ::

        InputStreamClass()
    """

    parent_class: Gio.InputStreamClass = ...
    _g_reserved1: None = ...
    _g_reserved2: None = ...
    _g_reserved3: None = ...
    _g_reserved4: None = ...
    _g_reserved5: None = ...

class InputStreamPrivate(GObject.GPointer): ...

class NetworkMonitor(GObject.GPointer):
    """
    :Constructors:

    ::

        NetworkMonitor()
    """

    parent_instance: None = ...
    priv: NetworkMonitorPrivate = ...

class NetworkMonitorClass(GObject.GPointer):
    """
    :Constructors:

    ::

        NetworkMonitorClass()
    """

    parent_class: None = ...

class NetworkMonitorPrivate(GObject.GPointer): ...

class OutputStream(Gio.OutputStream):
    """
    :Constructors:

    ::

        OutputStream(**properties)
        new(handle=None, close_handle:bool) -> Gio.OutputStream

    Object GWin32OutputStream

    Properties from GWin32OutputStream:
      handle -> gpointer: handle
      close-handle -> gboolean: close-handle

    Signals from GObject:
      notify (GParam)
    """

    parent_instance: Gio.OutputStream = ...
    priv: OutputStreamPrivate = ...
    @staticmethod
    def get_close_handle(stream: OutputStream) -> bool: ...
    @staticmethod
    def get_handle(stream: OutputStream) -> None: ...
    def new(
        handle: typing.Any, close_handle: bool
    ) -> OutputStream: ...  # FIXME Function
    @staticmethod
    def set_close_handle(stream: OutputStream, close_handle: bool) -> None: ...

class OutputStreamClass(GObject.GPointer):
    """
    :Constructors:

    ::

        OutputStreamClass()
    """

    parent_class: Gio.OutputStreamClass = ...
    _g_reserved1: None = ...
    _g_reserved2: None = ...
    _g_reserved3: None = ...
    _g_reserved4: None = ...
    _g_reserved5: None = ...

class OutputStreamPrivate(GObject.GPointer): ...



import typing

from gi.repository import Gio
from gi.repository import GLib
from gi.repository import GObject
from typing_extensions import Self

T = typing.TypeVar("T")

DESKTOP_APP_INFO_LOOKUP_EXTENSION_POINT_NAME: str = "gio-desktop-app-info-lookup"

def is_mount_path_system_internal(mount_path: str) -> bool: ...
def is_system_device_path(device_path: str) -> bool: ...
def is_system_fs_type(fs_type: str) -> bool: ...
def mount_at(mount_path: str) -> typing.Tuple[typing.Optional[MountEntry], int]: ...
def mount_compare(mount1: MountEntry, mount2: MountEntry) -> int: ...
def mount_copy(mount_entry: MountEntry) -> MountEntry: ...
def mount_entries_changed_since(time: int) -> bool: ...
def mount_entries_get() -> typing.Tuple[list[MountEntry], int]: ...
def mount_entries_get_from_file(
    table_path: str,
) -> typing.Tuple[typing.Optional[list[MountEntry]], int]: ...
def mount_entry_at(
    mount_path: str,
) -> typing.Tuple[typing.Optional[MountEntry], int]: ...
def mount_entry_for(
    file_path: str,
) -> typing.Tuple[typing.Optional[MountEntry], int]: ...
def mount_for(file_path: str) -> typing.Tuple[typing.Optional[MountEntry], int]: ...
def mount_free(mount_entry: MountEntry) -> None: ...
def mount_get_device_path(mount_entry: MountEntry) -> str: ...
def mount_get_fs_type(mount_entry: MountEntry) -> str: ...
def mount_get_mount_path(mount_entry: MountEntry) -> str: ...
def mount_get_options(mount_entry: MountEntry) -> typing.Optional[str]: ...
def mount_get_root_path(mount_entry: MountEntry) -> typing.Optional[str]: ...
def mount_guess_can_eject(mount_entry: MountEntry) -> bool: ...
def mount_guess_icon(mount_entry: MountEntry) -> Gio.Icon: ...
def mount_guess_name(mount_entry: MountEntry) -> str: ...
def mount_guess_should_display(mount_entry: MountEntry) -> bool: ...
def mount_guess_symbolic_icon(mount_entry: MountEntry) -> Gio.Icon: ...
def mount_is_readonly(mount_entry: MountEntry) -> bool: ...
def mount_is_system_internal(mount_entry: MountEntry) -> bool: ...
def mount_point_at(
    mount_path: str,
) -> typing.Tuple[typing.Optional[MountPoint], int]: ...
def mount_points_changed_since(time: int) -> bool: ...
def mount_points_get() -> typing.Tuple[list[MountPoint], int]: ...
def mount_points_get_from_file(
    table_path: str,
) -> typing.Tuple[typing.Optional[list[MountPoint]], int]: ...
def mounts_changed_since(time: int) -> bool: ...
def mounts_get() -> typing.Tuple[list[MountEntry], int]: ...
def mounts_get_from_file(
    table_path: str,
) -> typing.Tuple[typing.Optional[list[MountEntry]], int]: ...

class DesktopAppInfo(GObject.Object, Gio.AppInfo):
    """
    :Constructors:

    ::

        DesktopAppInfo(**properties)
        new(desktop_id:str) -> GioUnix.DesktopAppInfo or None
        new_from_filename(filename:str) -> GioUnix.DesktopAppInfo or None
        new_from_keyfile(key_file:GLib.KeyFile) -> GioUnix.DesktopAppInfo or None

    Object GDesktopAppInfo

    Properties from GDesktopAppInfo:
      filename -> gchararray: filename

    Signals from GObject:
      notify (GParam)
    """
    class Props(GObject.Object.Props):
        filename: typing.Optional[str]

    props: Props = ...
    def __init__(self, filename: str = ...) -> None: ...
    def get_action_name(self, action_name: str) -> str: ...
    def get_boolean(self, key: str) -> bool: ...
    def get_categories(self) -> typing.Optional[str]: ...
    def get_filename(self) -> typing.Optional[str]: ...
    def get_generic_name(self) -> typing.Optional[str]: ...
    @staticmethod
    def get_implementations(interface: str) -> list[DesktopAppInfo]: ...
    def get_is_hidden(self) -> bool: ...
    def get_keywords(self) -> list[str]: ...
    def get_locale_string(self, key: str) -> typing.Optional[str]: ...
    def get_nodisplay(self) -> bool: ...
    def get_show_in(self, desktop_env: typing.Optional[str] = None) -> bool: ...
    def get_startup_wm_class(self) -> typing.Optional[str]: ...
    def get_string(self, key: str) -> typing.Optional[str]: ...
    def get_string_list(self, key: str) -> list[str]: ...
    def has_key(self, key: str) -> bool: ...
    def launch_action(
        self,
        action_name: str,
        launch_context: typing.Optional[Gio.AppLaunchContext] = None,
    ) -> None: ...
    def launch_uris_as_manager(
        self,
        uris: list[str],
        launch_context: typing.Optional[Gio.AppLaunchContext],
        spawn_flags: GLib.SpawnFlags,
        user_setup: typing.Optional[typing.Callable[..., None]] = None,
        pid_callback: typing.Optional[typing.Callable[..., None]] = None,
        *pid_callback_data: typing.Any,
    ) -> bool: ...
    def launch_uris_as_manager_with_fds(
        self,
        uris: list[str],
        launch_context: typing.Optional[Gio.AppLaunchContext],
        spawn_flags: GLib.SpawnFlags,
        user_setup: typing.Optional[typing.Callable[..., None]],
        pid_callback: typing.Optional[typing.Callable[..., None]],
        stdin_fd: int,
        stdout_fd: int,
        stderr_fd: int,
        *pid_callback_data: typing.Any,
    ) -> bool: ...
    def list_actions(self) -> list[str]: ...
    @classmethod
    def new(cls, desktop_id: str) -> typing.Optional[DesktopAppInfo]: ...
    @classmethod
    def new_from_filename(cls, filename: str) -> typing.Optional[DesktopAppInfo]: ...
    @classmethod
    def new_from_keyfile(
        cls, key_file: GLib.KeyFile
    ) -> typing.Optional[DesktopAppInfo]: ...
    @staticmethod
    def search(search_string: str) -> list[typing.Sequence[str]]: ...
    @staticmethod
    def set_desktop_env(desktop_env: str) -> None: ...

class DesktopAppInfoClass(GObject.GPointer):
    """
    :Constructors:

    ::

        DesktopAppInfoClass()
    """

    parent_class: GObject.ObjectClass = ...

class DesktopAppInfoLookup(GObject.GInterface):
    """
    Interface GDesktopAppInfoLookup

    Signals from GObject:
      notify (GParam)
    """
    def get_default_for_uri_scheme(
        self, uri_scheme: str
    ) -> typing.Optional[Gio.AppInfo]: ...

class DesktopAppInfoLookupIface(GObject.GPointer):
    """
    :Constructors:

    ::

        DesktopAppInfoLookupIface()
    """

    g_iface: GObject.TypeInterface = ...
    get_default_for_uri_scheme: typing.Callable[
        [DesktopAppInfoLookup, str], typing.Optional[Gio.AppInfo]
    ] = ...

class FDMessage(Gio.SocketControlMessage):
    """
    :Constructors:

    ::

        FDMessage(**properties)
        new() -> Gio.SocketControlMessage
        new_with_fd_list(fd_list:Gio.UnixFDList) -> Gio.SocketControlMessage

    Object GUnixFDMessage

    Properties from GUnixFDMessage:
      fd-list -> GUnixFDList: fd-list

    Signals from GObject:
      notify (GParam)
    """
    class Props(Gio.SocketControlMessage.Props):
        fd_list: Gio.UnixFDList

    props: Props = ...
    parent_instance: Gio.SocketControlMessage = ...
    priv: FDMessagePrivate = ...
    def __init__(self, fd_list: Gio.UnixFDList = ...) -> None: ...
    def append_fd(self, fd: int) -> bool: ...
    def get_fd_list(self) -> Gio.UnixFDList: ...
    @classmethod
    def new(cls) -> FDMessage: ...
    @classmethod
    def new_with_fd_list(cls, fd_list: Gio.UnixFDList) -> FDMessage: ...
    def steal_fds(self) -> list[int]: ...

class FDMessageClass(GObject.GPointer):
    """
    :Constructors:

    ::

        FDMessageClass()
    """

    parent_class: Gio.SocketControlMessageClass = ...

class FDMessagePrivate(GObject.GPointer): ...

class FileDescriptorBased(GObject.GInterface):
    """
    Interface GFileDescriptorBased

    Signals from GObject:
      notify (GParam)
    """
    def get_fd(self) -> int: ...

class FileDescriptorBasedIface(GObject.GPointer):
    """
    :Constructors:

    ::

        FileDescriptorBasedIface()
    """

    g_iface: GObject.TypeInterface = ...
    get_fd: typing.Callable[[FileDescriptorBased], int] = ...

class InputStream(Gio.InputStream, Gio.PollableInputStream, FileDescriptorBased):
    """
    :Constructors:

    ::

        InputStream(**properties)
        new(fd:int, close_fd:bool) -> Gio.InputStream

    Object GUnixInputStream

    Properties from GUnixInputStream:
      fd -> gint: fd
      close-fd -> gboolean: close-fd

    Signals from GObject:
      notify (GParam)
    """
    class Props(Gio.InputStream.Props):
        close_fd: bool
        fd: int

    props: Props = ...
    parent_instance: Gio.InputStream = ...
    priv: InputStreamPrivate = ...
    def __init__(self, close_fd: bool = ..., fd: int = ...) -> None: ...
    def get_close_fd(self) -> bool: ...
    def get_fd(self) -> int: ...
    @classmethod
    def new(cls, fd: int, close_fd: bool) -> InputStream: ...
    def set_close_fd(self, close_fd: bool) -> None: ...

class InputStreamClass(GObject.GPointer):
    """
    :Constructors:

    ::

        InputStreamClass()
    """

    parent_class: Gio.InputStreamClass = ...

class InputStreamPrivate(GObject.GPointer): ...

class MountEntry(GObject.GBoxed):
    @staticmethod
    def at(mount_path: str) -> typing.Tuple[typing.Optional[MountEntry], int]: ...
    def compare(self, mount2: MountEntry) -> int: ...
    def copy(self) -> MountEntry: ...
    @staticmethod
    def for_(file_path: str) -> typing.Tuple[typing.Optional[MountEntry], int]: ...
    def free(self) -> None: ...
    def get_device_path(self) -> str: ...
    def get_fs_type(self) -> str: ...
    def get_mount_path(self) -> str: ...
    def get_options(self) -> typing.Optional[str]: ...
    def get_root_path(self) -> typing.Optional[str]: ...
    def guess_can_eject(self) -> bool: ...
    def guess_icon(self) -> Gio.Icon: ...
    def guess_name(self) -> str: ...
    def guess_should_display(self) -> bool: ...
    def guess_symbolic_icon(self) -> Gio.Icon: ...
    def is_readonly(self) -> bool: ...
    def is_system_internal(self) -> bool: ...

class MountMonitor(GObject.Object):
    """
    :Constructors:

    ::

        MountMonitor(**properties)
        new() -> GioUnix.MountMonitor

    Object GUnixMountMonitor

    Signals from GUnixMountMonitor:
      mounts-changed ()
      mountpoints-changed ()

    Signals from GObject:
      notify (GParam)
    """
    @staticmethod
    def get() -> MountMonitor: ...
    @classmethod
    def new(cls) -> MountMonitor: ...
    def set_rate_limit(self, limit_msec: int) -> None: ...

class MountMonitorClass(GObject.GPointer): ...

class MountPoint(GObject.GBoxed):
    @staticmethod
    def at(mount_path: str) -> typing.Tuple[typing.Optional[MountPoint], int]: ...
    def compare(self, mount2: MountPoint) -> int: ...
    def copy(self) -> MountPoint: ...
    def free(self) -> None: ...
    def get_device_path(self) -> str: ...
    def get_fs_type(self) -> str: ...
    def get_mount_path(self) -> str: ...
    def get_options(self) -> typing.Optional[str]: ...
    def guess_can_eject(self) -> bool: ...
    def guess_icon(self) -> Gio.Icon: ...
    def guess_name(self) -> str: ...
    def guess_symbolic_icon(self) -> Gio.Icon: ...
    def is_loopback(self) -> bool: ...
    def is_readonly(self) -> bool: ...
    def is_user_mountable(self) -> bool: ...

class OutputStream(Gio.OutputStream, Gio.PollableOutputStream, FileDescriptorBased):
    """
    :Constructors:

    ::

        OutputStream(**properties)
        new(fd:int, close_fd:bool) -> Gio.OutputStream

    Object GUnixOutputStream

    Properties from GUnixOutputStream:
      fd -> gint: fd
      close-fd -> gboolean: close-fd

    Signals from GObject:
      notify (GParam)
    """
    class Props(Gio.OutputStream.Props):
        close_fd: bool
        fd: int

    props: Props = ...
    parent_instance: Gio.OutputStream = ...
    priv: OutputStreamPrivate = ...
    def __init__(self, close_fd: bool = ..., fd: int = ...) -> None: ...
    def get_close_fd(self) -> bool: ...
    def get_fd(self) -> int: ...
    @classmethod
    def new(cls, fd: int, close_fd: bool) -> OutputStream: ...
    def set_close_fd(self, close_fd: bool) -> None: ...

class OutputStreamClass(GObject.GPointer):
    """
    :Constructors:

    ::

        OutputStreamClass()
    """

    parent_class: Gio.OutputStreamClass = ...

class OutputStreamPrivate(GObject.GPointer): ...
